@@ -30,8 +30,6 @@ from gnomad.utils.vcf import (
     IN_SILICO_ANNOTATIONS_INFO_DICT,
     make_info_dict,
     make_vcf_filter_dict,
-    REGION_FLAG_FIELDS,
-    RF_FIELDS,
     SITE_FIELDS,
     VQSR_FIELDS, make_hist_bin_edges_expr,
 )
@@ -77,6 +75,7 @@ SUBSET_LIST_FOR_VCF = remove_fields_from_constant(
 
 # Remove decoy from region field flag
 MISSING_REGION_FIELDS = ['decoy']
+REGION_FLAG_FIELDS = ['decoy', 'lcr', 'non_par', 'segdup']
 REGION_FLAG_FIELDS = remove_fields_from_constant(
     REGION_FLAG_FIELDS, MISSING_REGION_FIELDS
 )
@@ -85,7 +84,6 @@ REGION_FLAG_FIELDS = remove_fields_from_constant(
 MISSING_INFO_FIELDS = (
     MISSING_ALLELE_TYPE_FIELDS
     + MISSING_REGION_FIELDS
-    + RF_FIELDS
 )
 
 # Remove unnecessary pop names from POP_NAMES dict
@@ -174,11 +172,11 @@ def main(
     # Setup of parameters and Table/MatrixTable
     parameter_dict = _build_parameter_dict(ht, is_public_subset)
     
-    try:
-        age_hist_data = hl.eval(ht.age_distribution)
-    except AttributeError:
-        logger.warning('Age data not available')
-        age_hist_data = None
+    # try:
+    #     age_hist_data = hl.eval(ht.age_distribution)
+    # except AttributeError:
+    #     logger.warning('Age data not available')
+    age_hist_data = None
 
     vcf_ht = _prepare_vcf_ht(
         ht, 
@@ -196,7 +194,7 @@ def main(
     )
     
     logger.info('Cleaning up the VCF HT for final export...')
-    vcf_ht = _cleanup_ht_for_vcf_export(
+    vcf_ht, _ = _cleanup_ht_for_vcf_export(
         vcf_ht,
         drop_freqs=list(hl.eval(vcf_ht.freq_entries_to_remove)),
         drop_hists=parameter_dict['drop_hists'],        
@@ -222,21 +220,25 @@ def _prepare_vcf_header_dict(
     age_hist_data: Optional[str] = None,
 ) -> Dict:
     logger.info('Making histogram bin edges...')
-    bin_edges = make_hist_bin_edges_expr(
-        ht,
-        prefix=COHORT if is_public_subset else '',
-        include_age_hists=parameter_dict['include_age_hists'],
-    )
+
+    # Doesn't work because raw_qual_hists.* are not defined for 
+    # the first row (ht.head(1)...[0]):
+    # bin_edges = make_hist_bin_edges_expr(
+    #     ht,
+    #     prefix=COHORT if is_public_subset else '',
+    #     # include_age_hists=parameter_dict['include_age_hists'],
+    #     include_age_hists=False,
+    # )
     ht.describe()
     
     header_dict = prepare_vcf_header_dict(
         vcf_ht,
-        bin_edges=bin_edges,
         age_hist_data=age_hist_data,
         subset_list=parameter_dict['subsets'],
         pops=parameter_dict['pops'],
         filtering_model_field=parameter_dict['filtering_model_field'],
         inbreeding_coeff_cutoff=ht.inbreeding_coeff_cutoff,
+        bin_edges=None,
     )
     if not is_public_subset:
         header_dict.pop('format')
@@ -391,6 +393,8 @@ def populate_info_dict(
 
     if age_hist_data:
         age_hist_data = '|'.join(str(x) for x in age_hist_data)
+        
+    assert age_hist_data is None
 
     vcf_info_dict.update(
         make_info_dict(
@@ -433,8 +437,8 @@ def make_info_expr(
         vcf_info_dict[field] = t['vqsr'][f'{field}']
 
     # Add region_flag and allele_info fields to info dict
-    for field in ALLELE_TYPE_FIELDS:
-        vcf_info_dict[field] = t['allele_info'][f'{field}']
+    # for field in ALLELE_TYPE_FIELDS:
+    #     vcf_info_dict[field] = t['allele_info'][f'{field}']
     for field in REGION_FLAG_FIELDS:
         vcf_info_dict[field] = t['region_flag'][f'{field}']
 
@@ -454,21 +458,21 @@ def make_info_expr(
             f'{hist}_bin_freq': hl.delimit(t[hist_type][hist].bin_freq, delimiter='|'),
         }
         vcf_info_dict.update(hist_dict)
-
-        if 'dp' in hist:
-            vcf_info_dict.update({f'{hist}_n_larger': t[hist_type][hist].n_larger},)
+        # 
+        # if 'dp' in hist:
+        #     vcf_info_dict.update({f'{hist}_n_larger': t[hist_type][hist].n_larger},)
 
     # Add in silico annotations to info dict
-    vcf_info_dict['cadd_raw_score'] = t['cadd']['raw_score']
-    vcf_info_dict['cadd_phred'] = t['cadd']['phred']
+    # vcf_info_dict['cadd_raw_score'] = t['cadd']['raw_score']
+    # vcf_info_dict['cadd_phred'] = t['cadd']['phred']
 
-    vcf_info_dict['revel_score'] = t['revel']['revel_score']
+    # vcf_info_dict['revel_score'] = t['revel']['revel_score']
 
     # In the v3.1 release in silico files this was max_ds, but changed to splice_ai_score in releases after v3.1
-    vcf_info_dict['splice_ai_max_ds'] = t['splice_ai']['splice_ai_score']
-    vcf_info_dict['splice_ai_consequence'] = t['splice_ai']['splice_consequence']
+    # vcf_info_dict['splice_ai_max_ds'] = t['splice_ai']['splice_ai_score']
+    # vcf_info_dict['splice_ai_consequence'] = t['splice_ai']['splice_consequence']
 
-    vcf_info_dict['primate_ai_score'] = t['primate_ai']['primate_ai_score']
+    # vcf_info_dict['primate_ai_score'] = t['primate_ai']['primate_ai_score']
 
     return vcf_info_dict
 
@@ -752,16 +756,19 @@ def _prepare_vcf_ht(
     #   info struct (unfurled data obtained above),
     #   dbSNP rsIDs
     #   all VEP annotations
-    ht = ht.annotate(info=ht.info.annotate(**info_expr, vep=ht.vep))
+    ht = ht.annotate(info=ht.info.annotate(
+        **info_expr, 
+        # vep=ht.vep
+    ))
 
     if freq_entries_to_remove:
         ht = ht.annotate_globals(
-            vep_csq_header=vep_csq_header, 
+            # vep_csq_header=vep_csq_header, 
             freq_entries_to_remove=freq_entries_to_remove
         )
     else:
         ht = ht.annotate_globals(
-            vep_csq_header=vep_csq_header, 
+            # vep_csq_header=vep_csq_header, 
             freq_entries_to_remove=hl.empty_set(hl.tstr),
         )
         
@@ -773,13 +780,13 @@ def _prepare_vcf_ht(
 
 def prepare_vcf_header_dict(
     t: Union[hl.Table, hl.MatrixTable],
-    bin_edges: Dict[str, str],
     subset_list: List[str],
     pops: Dict[str, str],
     filtering_model_field: str = 'filtering_model',
     format_dict: Dict[str, Dict[str, str]] = FORMAT_DICT,
     inbreeding_coeff_cutoff: float = INBREEDING_COEFF_HARD_CUTOFF,
     age_hist_data: Optional[str] = None,
+    bin_edges: Optional[Dict[str, str]] = None,
 ) -> Dict[str, Dict[str, str]]:
     """
     Prepare VCF header dictionary.
@@ -809,7 +816,7 @@ def prepare_vcf_header_dict(
         subset_list=subset_list,
         subset_pops=pops,
     )
-    vcf_info_dict.update({'vep': {'Description': hl.eval(t.vep_csq_header)}})
+    # vcf_info_dict.update({'vep': {'Description': hl.eval(t.vep_csq_header)}})
 
     # Adjust keys to remove adj tags before exporting to VCF
     # VCF 4.3 specs do not allow hyphens in info fields
@@ -909,7 +916,8 @@ def _build_parameter_dict(
             'pops': POPS,
             'subsets': SUBSET_LIST_FOR_VCF,
             'is_subset': False,
-            'drop_hists': ['age_hist_het_bin_edges', 'age_hist_hom_bin_edges'],
+            'drop_hists': [],
+            # 'drop_hists': ['age_hist_het_bin_edges', 'age_hist_hom_bin_edges'],
             'include_age_hists': True,
             'sample_sum_sets_and_pops': {'hgdp': HGDP_POPS, 'thousand-genomes': TGP_POPS},
         }
